Fix typos in doc string in sponsor.py and settings.py
authorPawel Solyga <Pawel.Solyga@gmail.com>
Mon, 13 Oct 2008 22:18:54 +0000
changeset 318 e8eeccd7ef0f
parent 317 87215136c268
child 319 4e336befdf86
Fix typos in doc string in sponsor.py and settings.py Patch by: Pawel Solyga Review by: to-be-reviewed
app/soc/logic/models/settings.py
app/soc/logic/models/sponsor.py
--- a/app/soc/logic/models/sponsor.py	Mon Oct 13 22:04:42 2008 +0000
+++ b/app/soc/logic/models/sponsor.py	Mon Oct 13 22:18:54 2008 +0000
@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Settings (Model) query functions.
+"""Sponsor (Model) query functions.
 """
 
 __authors__ = [
--- a/app/soc/logic/models/settings.py	Mon Oct 13 22:04:42 2008 +0000
+++ b/app/soc/logic/models/settings.py	Mon Oct 13 22:18:54 2008 +0000
@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
 """Settings (Model) query functions.
 """
 
 __authors__ = [
@@ -29,14 +29,14 @@
 
 
 class Logic(base.Logic):
   """Logic methods for the Settings model
   """
 
   def __init__(self):
     """Defines the name, key_name and model for this entity.
     """
 
-    self._name = "settings"
+    self._name = "site_settings"
     self._model = soc.models.site_settings.SiteSettings
     self._keyName = key_name.nameSiteSettings
     self._skip_properties = []
@@ -14,7 +14,7 @@
 # limitations under the License.
 
-"""Settings (Model) query functions.
+"""SiteSettings (Model) query functions.
 """
 
@@ -29,14 +29,14 @@
 
 class Logic(base.Logic):
-  """Logic methods for the Settings model
+  """Logic methods for the SiteSettings model
   """
 